pub struct MultiDegreeElement<const N: usize> {
degree: MultiDegree<N>,
vec: FpVector,
}Expand description
An element of a graded vector space. Most commonly used to index elements of spectral sequences.
Fields
degree: MultiDegree<N>Degree of the element
vec: FpVectorRepresenting vector
Implementations
Sourceimpl<const N: usize> MultiDegreeElement<N>
impl<const N: usize> MultiDegreeElement<N>
pub fn new(degree: MultiDegree<N>, vec: FpVector) -> Self
pub fn s(&self) -> i32
pub fn t(&self) -> i32
pub fn degree(&self) -> MultiDegree<N>
pub fn n(&self) -> i32
pub fn x(&self) -> i32
pub fn y(&self) -> i32
pub fn vec(&self) -> FpSlice<'_>
pub fn into_vec(self) -> FpVector
Sourcepub fn to_basis_string(&self) -> String
pub fn to_basis_string(&self) -> String
Get the string representation of the element as a linear combination of generators. For
example, an element in bidegree (n,s) with vector [0,2,1] will be printed as `2 x_(n, s,
-
- x_(n, s, 2)`.