pub struct BidegreeRange<'a, T> {
s: i32,
t: &'a (dyn Fn(&T, i32) -> i32 + Sync),
aux: &'a T,
}Expand description
A range of bidegrees, corresponding to all s up to a given value, and for each of them, a
maximum t.
Fields
s: i32The maximal value of s in the range.
t: &'a (dyn Fn(&T, i32) -> i32 + Sync)The function that gives, for a given value of s, the maximum value for t.
aux: &'a TAuxillary data that t may depend on.
Implementations